pub trait DefaultConfig: DefaultConfig {
type RuntimeEvent;
type RuntimeHoldReason;
type RuntimeFreezeReason;
type WeightInfo: WeightInfo;
type Balance: Parameter + Member + AtLeast32BitUnsigned + Codec + HasCompact<Type: DecodeWithMemTracking> + Default + Copy + MaybeSerializeDeserialize + Debug + MaxEncodedLen + TypeInfo + FixedPointOperand;
type DustRemoval;
type ExistentialDeposit;
type ReserveIdentifier: Parameter + Member + MaxEncodedLen + Ord + Copy;
type MaxLocks: Get<u32>;
type MaxReserves: Get<u32>;
type DoneSlashHandler: DoneSlash<Self::RuntimeHoldReason, Self::AccountId, Self::Balance>;
}Expand description
Based on Config. Auto-generated by
#[pallet::config(with_default)].
Can be used in tandem with
#[register_default_config] and
#[derive_impl] to derive test config traits
based on existing pallet config traits in a safe and developer-friendly way.
See here for more information and caveats about
the auto-generated DefaultConfig trait and how it is generated.
Required Associated Types
Sourcetype RuntimeEvent
type RuntimeEvent
The overarching event type.
Sourcetype RuntimeHoldReason
type RuntimeHoldReason
The overarching hold reason.
Sourcetype RuntimeFreezeReason
type RuntimeFreezeReason
The overarching freeze reason.
This is also the identifier used for Freezes, and its variant count bounds the
number of freezes an account can hold at any time.
Sourcetype WeightInfo: WeightInfo
type WeightInfo: WeightInfo
Weight information for extrinsics in this pallet.
Sourcetype Balance: Parameter + Member + AtLeast32BitUnsigned + Codec + HasCompact<Type: DecodeWithMemTracking> + Default + Copy + MaybeSerializeDeserialize + Debug + MaxEncodedLen + TypeInfo + FixedPointOperand
type Balance: Parameter + Member + AtLeast32BitUnsigned + Codec + HasCompact<Type: DecodeWithMemTracking> + Default + Copy + MaybeSerializeDeserialize + Debug + MaxEncodedLen + TypeInfo + FixedPointOperand
The balance of an account.
Sourcetype DustRemoval
type DustRemoval
Handler for the unbalanced reduction when removing a dust account.
Sourcetype ExistentialDeposit
type ExistentialDeposit
The minimum amount required to keep an account open. MUST BE GREATER THAN ZERO!
If you really need it to be zero, you can enable the feature insecure_zero_ed for
this pallet. However, you do so at your own risk: this will open up a major DoS vector.
In case you have multiple sources of provider references, you may also get unexpected
behaviour if you set this to zero.
Bottom line: Do yourself a favour and make it at least one!
Sourcetype ReserveIdentifier: Parameter + Member + MaxEncodedLen + Ord + Copy
type ReserveIdentifier: Parameter + Member + MaxEncodedLen + Ord + Copy
The ID type for reserves.
Use of reserves is deprecated in favour of holds. See https://github.com/paritytech/substrate/pull/12951/
Sourcetype MaxLocks: Get<u32>
type MaxLocks: Get<u32>
The maximum number of locks that should exist on an account. Not strictly enforced, but used for weight estimation.
Use of locks is deprecated in favour of freezes. See https://github.com/paritytech/substrate/pull/12951/
Sourcetype MaxReserves: Get<u32>
type MaxReserves: Get<u32>
The maximum number of named reserves that can exist on an account.
Use of reserves is deprecated in favour of holds. See https://github.com/paritytech/substrate/pull/12951/
Sourcetype DoneSlashHandler: DoneSlash<Self::RuntimeHoldReason, Self::AccountId, Self::Balance>
type DoneSlashHandler: DoneSlash<Self::RuntimeHoldReason, Self::AccountId, Self::Balance>
Allows callbacks to other pallets so they can update their bookkeeping when a slash occurs.